# The client

When you are looking to integrate iCal-library with your project, the `client` is the first place to look.
If you have a service that periodically restarts, you might want to take a look at the `CacheClient`.

::: ical_library.client
    